@@ -239,12 +239,12 @@ editor_method_check_word (GtkHTML *html,
                           gpointer user_data)
 {
 	GtkhtmlEditor *editor = user_data;
-	gboolean correct = TRUE;
+	gboolean correct = FALSE;
 	GList *list;
 
 	list = editor->priv->active_spell_checkers;
 
-	while (list != NULL && correct) {
+	while (list != NULL && !correct) {
 		GtkhtmlSpellChecker *checker = list->data;
 
 		correct = gtkhtml_spell_checker_check_word (checker, word, -1);
@@ -830,6 +830,7 @@ editor_init (GtkhtmlEditor *editor)
 	editor->vbox = g_object_ref_sink (gtk_vbox_new (FALSE, 0));
 	gtk_widget_show (editor->vbox);
 
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	gtkhtml_editor_private_init (editor);
