@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Author: Ettore Perazzoli <ettore@helixcode.com>
 */
@@ -112,7 +112,7 @@ static void
 apply_color (GdkColor *gdk_color, GtkHTMLControlData *cd)
 {
 	HTMLColor *color;
-	
+
 	color = gdk_color
 		&& gdk_color != &html_colorset_get_color (cd->html->engine->settings->color_set, HTMLTextColor)->color
 		? html_color_new_from_gdk_color (gdk_color) : NULL;
@@ -495,31 +495,33 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	GtkIconInfo *icon_info;
 	GtkWidget *hbox;
 	gchar *domain;
-	
+
 	hbox = gtk_hbox_new (FALSE, 0);
 
 	cd->toolbar_style = gtk_toolbar_new ();
 	gtk_box_pack_start (GTK_BOX (hbox), cd->toolbar_style, TRUE, TRUE, 0);
 
 	cd->paragraph_option = paragraph_style_combo_box_new (cd);
+	g_object_set (G_OBJECT (cd->paragraph_option), "focus-on-click", FALSE, NULL);
 	gtk_toolbar_prepend_space (GTK_TOOLBAR (cd->toolbar_style));
 	gtk_toolbar_prepend_widget (GTK_TOOLBAR (cd->toolbar_style),
 				    cd->paragraph_option,
 				    NULL, NULL);
 
 	cd->font_size_menu = setup_font_size_combo_box (cd);
+	g_object_set (G_OBJECT (cd->font_size_menu), "focus-on-click", FALSE, NULL);
 	gtk_toolbar_prepend_space (GTK_TOOLBAR (cd->toolbar_style));
 	gtk_toolbar_prepend_widget (GTK_TOOLBAR (cd->toolbar_style),
 				    cd->font_size_menu,
 				    NULL, NULL);
 
-	/* 
-	 * FIXME: steal textdomain temporarily from main-process,  and set it to 
+	/*
+	 * FIXME: steal textdomain temporarily from main-process,  and set it to
 	 * GETTEXT_PACKAGE, after create the widgets, restore it.
 	 */
 	domain = g_strdup (textdomain (NULL));
 	textdomain (GETTEXT_PACKAGE);
-	
+
 	icon_info = gtk_icon_theme_lookup_icon (
 		gtk_icon_theme_get_default (),
 		"stock_text-monospaced", 24, 0);
@@ -535,7 +537,7 @@ create_style_toolbar (GtkHTMLControlData *cd)
 
 	gtk_toolbar_append_widget (GTK_TOOLBAR (cd->toolbar_style),
 				   setup_gi_color_combo (cd),
-				   NULL, NULL);
+				   _("Text Color"), NULL);
 
 	cd->font_style_changed_connection_id
 		= g_signal_connect (GTK_OBJECT (cd->html), "insertion_font_style_changed",
@@ -617,7 +619,7 @@ void
 toolbar_update_format (GtkHTMLControlData *cd)
 {
 	if (cd->toolbar_style)
-		gtk_container_foreach (GTK_CONTAINER (cd->toolbar_style), 
+		gtk_container_foreach (GTK_CONTAINER (cd->toolbar_style),
 		toolbar_item_update_sensitivity, cd);
 }
 
