@@ -38,19 +38,20 @@ copy (HTMLObject *self,
 }
 
 static gchar *
-encode (HTMLEmbedded *e, const gchar *codepage)
+encode (HTMLEmbedded *e)
 {
 	GString *encoding = g_string_new ("");
 	gchar *ptr;
 
-	if (strlen (e->name) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->widget))) {
+	if(strlen (e->name) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->widget))) {
 
-		ptr = html_embedded_encode_string (e->name, codepage);
+		ptr = html_embedded_encode_string (e->name);
 		encoding = g_string_append (encoding, ptr);
 		g_free (ptr);
 
 		encoding = g_string_append_c (encoding, '=');
-		ptr = html_embedded_encode_string (e->value, codepage);
+
+		ptr = html_embedded_encode_string (e->value);
 		encoding = g_string_append (encoding, ptr);
 		g_free (ptr);
 	}
@@ -83,6 +84,7 @@ html_checkbox_class_init (HTMLCheckBoxClass *klass,
 	HTMLEmbeddedClass *element_class;
 	HTMLObjectClass *object_class;
 
+
 	element_class = HTML_EMBEDDED_CLASS (klass);
 	object_class = HTML_OBJECT_CLASS (klass);
 
